@@ -15,6 +15,7 @@ class config:
             sys.path.insert(1, lib_path)
         else:
             lib_path = os.path.join(os.environ.get("HOME"), "Library/CloudStorage/OneDrive-MoneseLtd/GW/libraries/snowflake")
+            /Users/geofrey.wanyama/Desktop/libraries/environ_vars/.env
             sys.path.insert(1, lib_path)  
     
     def get_credentials(env_path=None):
@@ -28,6 +29,8 @@ class config:
     
     def get_logger(file=None):
 
+
+
         logger = logging.getLogger('logger_name')
 
         logger.setLevel(logging.INFO)
@@ -46,6 +49,11 @@ class config:
 
         if file:
 
+            if not os.path.isdir('model_artefacts'):
+                os.mdir('model_artefacts')
+
+            path = os.path.join('model_artefacts', file)
+
             filehandler = logging.FileHandler(file)
 
             filehandler.setLevel(logging.DEBUG)
