@@ -49,7 +49,7 @@ class xgb_training:
     """
 
     
-    def __init__(self, df, features, target, params_prop=0.25, test_size=0.33, hyperparams=None):
+    def __init__(self, df, features, target, params_prop=0.25, test_size=0.33, hyperparams=None, scoring='recall'):
         
         self.data = df
         
@@ -58,12 +58,16 @@ class xgb_training:
         self.target = target
         
         self.hyperparams = hyperparams
+
+        self.scoring = scoring
         
         self.cwd = os.getcwd()
         
         self.log = config.get_logger(file='xgbModelLogs.log')
         
-        self.path = os.path.join(self.cwd, 'xgb_model_results.json')
+        if not os.path.isdir('model_artefacts'):
+            os.mdir('model_artefacts')
+        self.path = os.path.join('model_artefacts', 'xgb_model_results.json')
         
         try:
             with open(self.path) as file:
@@ -270,12 +274,12 @@ class xgb_training:
         
         # predicted labels
         self.pred_class = self.model.predict(self.X_test[self.features])
-        self.model_artefacts[self.model_name]['pred_class'] = list(self.pred_class)
+        # self.model_artefacts[self.model_name]['pred_class'] = list(self.pred_class)
         self.log.info('Predicted labels generated (test)')
         
         # predicted probabilities
         self.pred_prob = self.model.predict_proba(self.X_test[self.features])[:,1]
-        self.model_artefacts[self.model_name]['pred_prob'] = list(self.pred_prob)
+        # self.model_artefacts[self.model_name]['pred_prob'] = list(self.pred_prob)
         self.log.info('Predicted probabilities generated (test)')
 
         # confusion matrix
@@ -357,6 +361,8 @@ class xgb_training:
         
         # saving all model artefacts
         json_object = json.dumps(self.model_artefacts, cls=NpEncoder, indent=4)
+
+
         with open(self.path, 'w') as outfile:
             outfile.write(json_object)
         
